#
# spec file for package watson
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}
Name:           watson
Version:        2.1.0
Release:        1.5
Summary:        CLI time tracker
License:        MIT
Group:          Productivity/Office/Organizers
URL:            https://github.com/TailorDev/Watson
Source:         https://github.com/TailorDev/Watson/archive/%{version}.tar.gz
BuildRequires:  python3-setuptools
Requires:       python3-arrow >= 1.0.0
Requires:       python3-click
Requires:       python3-click-didyoumean
Requires:       python3-requests
BuildArch:      noarch

%description
Watson helps managing time. It can tell how much time was spent on projects.
It generates reports for clients.

%package bash-completion
Summary:        Bash completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and bash)
BuildArch:      noarch

%description bash-completion
Bash command line completion support for %{name}.

%package fish-completion
Summary:        Fish completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description fish-completion
Fish command line completion support for %{name}.

%package zsh-completion
Summary:        Zsh completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description zsh-completion
Zsh command line completion support for %{name}.

%prep
%autosetup -n Watson-%{version}

%build
%python3_build

%install
%python3_install
install -D -m 0644 watson.zsh-completion %{buildroot}%{_datadir}/zsh/site-functions/_watson
mkdir -p %{buildroot}%{_datadir}%{_datadir}/fish/vendor_completions.d/
install -D -m 0644 watson.fish %{buildroot}%{_datadir}/fish/vendor_completions.d/watson.fish
install -D -m 0644 watson.completion  %{buildroot}%{_datadir}/bash-completion/completions/watson

%files
%license LICENSE
%doc CHANGELOG.md README.rst
%{_bindir}/watson
%{python_sitelib}/*

%files bash-completion
%{_datadir}/bash-completion/completions/

%files fish-completion
%dir %{_datadir}/fish/
%{_datadir}/fish/vendor_completions.d/

%files zsh-completion
%dir %{_datadir}/zsh/
%{_datadir}/zsh/site-functions/

%changelog
* Tue May 24 2022 Michael Vetter <mvetter@suse.com>
- Update to 2.1.0:
  Added:
  * The restart command now accepts the --gap/--no-gap options.
  Fixed:
  * Watson is now compatible with Click 8+
* Fri May 14 2021 Michael Vetter <mvetter@suse.com>
- Update to 2.0.1:
  * Ability to edit the current frame (#418)
* Wed Apr  7 2021 Michael Vetter <mvetter@suse.com>
- Update to 2.0.0:
  Added:
  * The log command output can now be filtered to exclude projects and tags via --ignore-project and --ignore-tag (#395)
  * Python 3.8 support (#402)
  * Python 3.9 support (#402)
  * Support for the TZ environment variable to specify the local time zone (#391)
  Changed:
  * Upgrade to major arrow release 1.0.0 (#407)
  Fixed:
  * Zsh completion (#379)
  Removed
  * Python 2.7 support (#305).
  * Python 3.5 support (#407).
* Sun Jul  5 2020 Michael Vetter <mvetter@suse.com>
- Upddate to 1.10.0:
  Added:
  * Log output order can now be controlled via the --reverse/--no-reverse
  flag and the reverse_log configuration option (#369)
  * Add --at flag to the start and restart commands (#364).
  * Add --color and --no-color flags to force output to be colored or not
  respectively (#350).
  Changed:
  * Require latest Arrow version 0.15.6 to support ISO week dates (#380)
  Fixed:
  * Make after-edit-check ensure that edited time stamps are not in the
  future (#381)
- Remove watson-arrow-version.patch:
  This release depends on python-arrow 0.15.6 anyways
* Fri Jun  5 2020 Michael Vetter <mvetter@suse.com>
- Add Requires on python3-click-didyoumean
- Add watson-arrow-version.patch:
  We have a newer python-arrow version which still works
* Thu May 28 2020 Michael Vetter <mvetter@suse.com>
- Use Supplements: packageand(%%{name}:bash) instead of Suggests
* Thu May 28 2020 Michael Vetter <mvetter@suse.com>
- Install bash, fish and zsh completions
* Thu May 28 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.9.0:
  Added:
  * Improve Arrow 0.15.0 support after changes in arrow.get() behavior
  (#296)
  * Watson now suggests correct command if users make small typo (#318)
  Changed:
  * Always show total time at bottom of report (#356)
  * Use the default system newline character for CSV output (#366).
  Fixed:
  * Stylize prompt to create new project or tag (#310).
  * Aggregate calculates wrong time if used with --current (#293)
  * The start command now correctly checks if project is empty (#322)
  * Aggregate ignores frames that crosses aggregate boundary (#248)
  * The report and aggregate commands with --json option now correctly
    encode Arrow objects (#329)
* Wed May 27 2020 Jan Engelhardt <jengelh@inai.de>
- Remove rhetorics from description. Use %%autosetup.
* Wed May 27 2020 Michael Vetter <mvetter@suse.com>
- Create watson 1.8.0 package for openSUSE
